from python_simple_menu import Menu
from python_simple_menu.items import FunctionItem
from python_simple_menu.items import MenuItem


def main():
    m = Menu(prompt="Main Menu")
    m.items.append(FunctionItem(label="Item 1", function=lambda: print("Item 1")))

    m2 = Menu(parent=m, prompt="Sub Menu 1")
    m2.items.append(FunctionItem(label="Item 2", function=lambda: print("Item 2")))
    m.items.append(MenuItem(label="Sub Menu 1", menu=m2))

    m.run()


if __name__ == "__main__":
    main()



from abc import ABC
from abc import abstractmethod
from typing import Callable
from typing import Dict
from typing import List
from typing import Optional
from typing import Union


class BaseItem(ABC):
    """
    All menu items should inherit from this
    """

    def __init__(self, label: str = ""):
        self.label = label

    @abstractmethod
    def exec(self):
        print(self.label)


class MenuItem(BaseItem):
    """
    Displays a sub-menu until the user chooses to go back or quit the app

    Attributes:
        label(str): the option text
        menu(Menu): the menu to execute
    """

    from .menu import Menu

    def __init__(self, menu: Menu, label: Optional[str] = None):
        super().__init__(label or menu.prompt)
        self.menu = menu

    def exec(self):
        self.menu.run()


class FunctionItem(BaseItem):
    """
    Executes a function when the item is chosen

    Attributes:
        label(str): the option text
        function(Callable): the function to execute
        args(List): positional arguments for the function
        kwargs(Dict): keyword arguments for the function
    """

    def __init__(
        self,
        label,
        function: Callable,
        args: Union[List, None] = [],
        kwargs: Union[Dict, None] = {},
    ):
        super().__init__(label)
        self.function = function
        self.args = args
        self.kwargs = kwargs

    def exec(self):
        self.function(*self.args, **self.kwargs)



from textwrap import fill

from python_simple_menu import Menu
from python_simple_menu.items import FunctionItem
from python_simple_menu.items import MenuItem


def main():
    main_menu = Menu(prompt="Contents")
    main_menu.items.append(FunctionItem("Preface", __preface))

    ch1_menu = Menu(
        parent=main_menu,
        prompt="Chapter 1: It Begins",
        prompt_go_back="Contents",
        prompt_quit="Good night!",
    )

    ch1_menu.items.append(FunctionItem("Close to Home", __ch1_close_to_home))
    ch1_menu.items.append(FunctionItem("Far Far Away", __ch1_far_far_away))
    main_menu.items.append(MenuItem(ch1_menu))
    main_menu.run()


def __print(text: str):
    print(fill(text, 70))


def __preface():
    __print(
        "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do; eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut; enim ad minim veniam, quis nostrud exercitation ullamco laboris; nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat; nulla pariatur. Excepteur sint occaecat cupidatat non proident,; sunt in culpa qui officia deserunt mollit anim id est laborum."
    )


def __ch1_close_to_home():
    __print(
        "Ullamcorper eget nulla facilisi etiam. Cras fermentum odio eu feugiat pretium. Phasellus faucibus scelerisque eleifend donec pretium vulputate sapien nec sagittis. Turpis nunc eget lorem dolor sed viverra ipsum nunc aliquet. Erat pellentesque adipiscing commodo elit at imperdiet dui accumsan sit. Tristique senectus et netus et malesuada. In iaculis nunc sed augue lacus viverra vitae congue. Leo vel fringilla est ullamcorper. ",
    )


def __ch1_far_far_away():
    __print(
        "Maecenas volutpat blandit aliquam etiam erat velit scelerisque in. Curabitur gravida arcu ac tortor dignissim convallis aenean. Sem fringilla ut morbi tincidunt augue interdum velit euismod. Sollicitudin aliquam ultrices sagittis orci a scelerisque purus semper. Ullamcorper malesuada proin libero nunc consequat. Mauris sit amet massa vitae tortor condimentum. Elementum facilisis leo vel fringilla.",
    )


if __name__ == "__main__":
    main()



from typing import List
from typing import Optional


class Menu:
    """
    Display a list of choices until the user chooses quit

    Example usage::

                                                                                                                                    from simple_menu.items import FunctionItem
                                                                                                                                    from simple_menu.items import MenuItem
                                                                                                                                    from simple_menu import Menu

                                                                                                                                    m = Menu(prompt="Main Menu")
                                                                                                                                    m.items.append(FunctionItem(label="Item 1", function=lambda: print("Item 2")))

                                                                                                                                    m2 = Menu(parent=m, prompt="Sub Menu 1")
                                                                                                                                    m2.items.append(FunctionItem(label="Item 2", function=lambda: print("Item 2")))
                                                                                                                                    m.items.append(MenuItem(label="Sub Menu 1", menu=m2))

                                                                                                                                    m.run()

    Attributes:

                                                                                                                                    prompt(str): The prompt before the item list (default: "Menu")
                                                                                                                                    prompt_quit(str): The prompt to quit the application (default: "Quit")
                                                                                                                                    prompt_go_back(str): The prompt to exit the sub-menu (default: "Back")
                                                                                                                                    parent(Menu|None): The parent menu this menu belongs to
    """

    def __init__(
        self,
        prompt="Menu",
        prompt_quit: Optional[str] = None,
        prompt_go_back: Optional[str] = None,
        parent: Optional["Menu"] = None,
    ):
        from .items import BaseItem

        if prompt_go_back is None:
            prompt_go_back = parent.prompt if parent else "Back"

        if prompt_quit is None:
            prompt_quit = parent.prompt_quit if parent else "Quit"

        self.prompt = prompt
        self.prompt_quit = prompt_quit
        self.prompt_go_back = prompt_go_back
        self.items: List[BaseItem] = []
        self.parent = parent

    def run(self):

        while True:
            print(self.prompt)

            # render each menu item
            for index, item in enumerate(self.items, start=1):
                print(f" {index}: {item.label}")

            # render "go back" prompt
            if self.parent:
                print(f" B: {self.prompt_go_back}")

            # render "quit" prompt
            print(f" Q: {self.prompt_quit}")

            try:
                choice = input("> ").strip()

                # go back to parent menu
                if choice.upper() == "B" and self.parent:
                    break

                # exit the application
                if choice.upper() == "Q":
                    exit(0)

                # execute the chosen item
                index = int(choice) - 1
                self.items[index].exec()
                continue

            except IndexError:
                print(f"Invalid choice. Try again.")

            except Exception as e:
                print(f"Error: {e}")
                continue



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['python_simple_menu', 'python_simple_menu.examples']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'python-simple-menu',
    'version': '1.1.14',
    'description': 'Yet another simple console menu',
    'long_description': '# python-simple-menu\n\nA lightweight console menu package for python applications. No frills, no fuss.\n\n## Installing\n\nTo install to your project, run the following command:\n\n```shell\npip install python_simple_menu\n```\n\n## How to use\n\n```python\ndef main():\n    main_menu = Menu(prompt="Main Menu")\n    main_menu.items.append(FunctionItem("Item 1", __item1))\n    main_menu.items.append(FunctionItem("Item 2", __item2))\n    \n    sub_menu1 = Menu(prompt="Sub-Menu 1", parent=main_menu)\n    sub_menu1.items.append(FunctionItem("Item 1", __item1))\n    sub_menu1.items.append(FunctionItem("Item 2", __item2))\n    \n    main_menu.items.append(MenuItem(sub_menu1))    \n    main_menu.run()\n\ndef __item1():\n    print(\'lorem ipsum...\')\n\ndef __item2():\n    print(\'dolor sit amet...\')\n```\n\nThe menu will run until the user chooses Quit ("Q"), which will exit the\napplication. If the menu has a parent menu, an additional Back ("B") option\nwill be rendered which will return the user to the parent menu.\n\nSee the `python_simple_menu/examples` directory for other usages.\n',
    'author': 'Chris Vann',
    'author_email': 'chrisvann01@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
